<?php
namespace magic;


class Cart
{
    private $content = null;
    private $allCards = null;

    public function __construct()
    {
        if(isset($_SESSION['cart'])){
            $this->content = $_SESSION['cart'] ;
        }else{
            $this->content = array() ;
        }

        // chargement de toutes les cartes
        $data = file_get_contents($GLOBALS['PHP_DIR']."data/cards.json") ;
        $this->allCards = json_decode($data) ;

    }

    public function add(array $selection): void{
        foreach ($selection as $id){
            //if (!array_key_exists($id, $this->allCards)) break ;
            if (!isset($this->allCards->$id)) break ;
            if(isset($this->content[$id])){
                $this->content[$id] += 1 ;
            }else{
                $this->content[$id] = 1 ;
            }

        }
        $_SESSION['cart'] = $this->content ;
    }

    public function update(array $cart): void{
        $this->content = array() ;
        foreach ($cart as $id=>$num){
            if (isset($this->allCards->$id) and $num>0){
                $this->content[$id] = $num ;
            }
        }
        $_SESSION['cart'] = $this->content ;
    }

    public function render():void{ ?>
        <form class="browser" action="update_cart.php" method="post" autocomplete="off">
            <header style="flex-direction: column ; justify-content: center">
                <h1 style="padding: 5px">CART : <span id="num-cards"></span>$</h1>
                <button type="submit" class="btn btn-danger" style="width: 100% ; margin: 0" id="update-cart">
                    UPDATE CART
                </button>
            </header>
            <div class="browser-content-wrapper">
                <div class="browser-content">
                <?php
                foreach ($this->content as $id => $num):
                    $c = $this->allCards->$id ;
                    ?>
                    <div class="magic-card selected">
                        <img src="<?php echo $c->image_uris->normal ?>">
                        <legend>
                            <label for="<?php echo $c->id ?>"><?php echo $c->name ?></label>
                            <input type="number"
                                   id="<?php echo $id ?>"
                                   name="<?php echo $id ?>"
                                   value="<?php echo $num ?>"
                            >
                        </legend>
                    </div>
                <?php endforeach; ?>
                </div>
            </div>
        </form>
        <script>
            let inputs = undefined
            let numCards = undefined
            let updateButton = undefined
            document.addEventListener('DOMContentLoaded', function (){
                numCards = document.getElementById('num-cards')
                updateButton = document.getElementById('update-cart')
                inputs = document.getElementsByTagName('input')
                for (input of inputs){
                    input.addEventListener('change', function (){
                        if(this.value !== this.defaultValue){
                            this.parentElement.parentElement.classList.remove('selected')
                            this.parentElement.parentElement.classList.add('edited')
                        }else{
                            this.parentElement.parentElement.classList.remove('edited')
                            this.parentElement.parentElement.classList.add('selected')
                        }
                        countItems()
                        styleButton()
                    })
                }
                countItems()
                styleButton()
            })

            function countItems(){
                const price = 25
                let count = 0
                for(input of inputs){
                    let val = parseInt(input.value)
                    val = val >= 0 ? val : 0
                    count += val
                }
                numCards.innerHTML = count*price/100
            }

            function styleButton(){
                let edited = document.getElementsByClassName('edited')
                updateButton.style.visibility = (edited.length != 0) ? 'visible' : 'hidden'
            }

        </script>
        <?php
    }

}